@@ -1,3 +1,5 @@
+-- | Please see the README.md file for information on using this
+-- package at <https://www.stackage.org/package/unliftio>.
 module UnliftIO
   ( module Control.Monad.IO.Unlift
   , module UnliftIO.Async
@@ -5,9 +7,8 @@ module UnliftIO
   , module UnliftIO.Exception
   , module UnliftIO.IO
   , module UnliftIO.IORef
-  , module UnliftIO.Instances
   , module UnliftIO.MVar
-  , module UnliftIO.Resource
+  , module UnliftIO.STM
   , module UnliftIO.Temporary
   , module UnliftIO.Timeout
   ) where
@@ -18,8 +19,7 @@ import UnliftIO.Chan
 import UnliftIO.Exception
 import UnliftIO.IO
 import UnliftIO.IORef
-import UnliftIO.Instances
 import UnliftIO.MVar
-import UnliftIO.Resource
+import UnliftIO.STM
 import UnliftIO.Temporary
 import UnliftIO.Timeout
